Module: Igniter::Store::Protocol
- Defined in:
- lib/igniter/store/protocol.rb,
lib/igniter/store/protocol/receipt.rb,
lib/igniter/store/protocol/interpreter.rb,
lib/igniter/store/protocol/sync_profile.rb,
lib/igniter/store/protocol/wire_envelope.rb,
lib/igniter/store/protocol/handlers/store_handler.rb,
lib/igniter/store/protocol/handlers/effect_handler.rb,
lib/igniter/store/protocol/handlers/command_handler.rb,
lib/igniter/store/protocol/handlers/history_handler.rb,
lib/igniter/store/protocol/handlers/relation_handler.rb,
lib/igniter/store/protocol/handlers/derivation_handler.rb,
lib/igniter/store/protocol/handlers/projection_handler.rb,
lib/igniter/store/protocol/handlers/access_path_handler.rb,
lib/igniter/store/protocol/handlers/subscription_handler.rb
Defined Under Namespace
Modules: Handlers Classes: Interpreter, Receipt, SyncProfile, WireEnvelope
Class Method Summary collapse
-
.new(store = nil) ⇒ Object
Convenience factory: Protocol.new returns a fresh Interpreter backed by an in-memory IgniterStore.
Class Method Details
.new(store = nil) ⇒ Object
Convenience factory: Protocol.new returns a fresh Interpreter backed by an in-memory IgniterStore. Pass an existing store to wrap it instead.
22 23 24 |
# File 'lib/igniter/store/protocol.rb', line 22 def self.new(store = nil) Interpreter.new(store || IgniterStore.new) end |